pycoSHARK
=========
.. image:: https://travis-ci.org/smartshark/pycoSHARK.svg?branch=master
    :target: https://travis-ci.org/smartshark/pycoSHARK

Python data collection library for SmartSHARK.


Install from Pypi
--------------

.. code-block:: bash

    $ sudo pip install pycoshark


Install latest
--------------

.. code-block:: bash

	$ sudo pip install https://github.com/smartshark/pycoSHARK/zipball/master



Install version 1.0.0
---------------------
.. code-block:: bash

	$ sudo pip install https://github.com/smartshark/pycoSHARK/archive/1.0.0.zip

Documentation
-------------
https://smartshark.github.io/pycoSHARK/
